<?php
/**
 * The template for displaying Archive pages.
 *
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 *
 * @package Mono
 */

global $mono_settings;

$post_layout  = $mono_settings->get_value( 'archive-posts-layout' );
$layout_class = 'grid';

if ( 'grid' == $post_layout ) {
	$layout_class .= ' posts-list';
} elseif ( 'tile' == $post_layout ) {
	$layout_class .= ' recent-posts-layout-tile';
} elseif ( 'compact' == $post_layout ) {
	$layout_class .= ' recent-posts-layout-compact';
}

$container_class = 'container';
if ( 'tile' == $post_layout ) {
	$container_class = 'container--tile';
}

get_header(); ?>

	<section id="primary" class="site-content">
		<div id="content" role="main">

			<div class="<?php echo esc_attr( $container_class ); ?>">
				<header class="page-header">
					<div class="container">
						<h1 class="page-title grid__col span-all">
							<?php if ( is_category() ) { ?>
									<small><?php esc_html_e( 'Showing all posts in Category:', 'mono' ); ?></small>
									<span><?php echo single_cat_title( '', false ); ?></span>

							<?php } elseif ( is_tag() ) { ?>
									<small><?php esc_html_e( 'Tag Archives:', 'mono' ); ?></small>
									<span><?php echo single_tag_title( '', false ); ?></span>

							<?php } elseif ( is_author() ) { ?>

									<?php
									/*
									 Queue the first post, that way we know
									 * what author we're dealing with (if that is the case).
									*/
									the_post();
									?>

									<small><?php esc_html_e( 'Author:', 'mono' ); ?></small>
									<span class="vcard"><?php the_author(); ?></span>

									<?php
									$author_description = get_the_author_meta( 'description' );
									if ( ! empty( $author_description ) ) {
										echo apply_filters( 'author_meta_description', '<div class="taxonomy-description">' . do_shortcode( $author_description ) . '</div>' );
									}

									/*
									 Since we called the_post() above, we need to
									 * rewind the loop back to the beginning that way
									 * we can run the loop properly, in full.
									 */
									rewind_posts();

							} elseif ( is_day() ) {
								?>
									<small><?php esc_html_e( 'Daily Archives:', 'mono' ); ?></small>
									<span><?php echo get_the_date(); ?></span>

							<?php } elseif ( is_month() ) { ?>
									<small><?php esc_html_e( 'Monthly Archives:', 'mono' ); ?></small>
									<span><?php echo get_the_date( 'F Y' ); ?></span>

							<?php } elseif ( is_year() ) { ?>
									<small><?php esc_html_e( 'Yearly Archives:', 'mono' ); ?></small>
									<span><?php echo get_the_date( 'Y' ); ?></span>

							<?php } else { ?>
									<small><?php esc_html_e( 'Archives:', 'mono' ); ?></small>
							<?php } ?>
						</h1>
						<?php
						if ( is_category() ) {
							// show an optional category description.
							$category_description = category_description();
							if ( ! empty( $category_description ) ) {
								echo apply_filters( 'category_archive_meta', '<div class="taxonomy-description">' . $category_description . '</div>' );
							}
						} elseif ( is_tag() ) {
							// show an optional tag description.
							$tag_description = tag_description();
							if ( ! empty( $tag_description ) ) {
								echo apply_filters( 'tag_archive_meta', '<div class="taxonomy-description">' . $tag_description . '</div>' );
							}
						}
						?>
					</div>
				</header><!-- .page-header -->

				<?php rewind_posts(); ?>

				<div class="<?php echo esc_attr( $layout_class ); ?>">
					<?php if ( have_posts() ) : ?>

						<?php /* Start the Loop */ ?>
						<?php
						while ( have_posts() ) :
							the_post();
							?>

							<?php
								/*
								 Include the Post-Format-specific template for the content.
								 * If you want to overload this in a child theme then include a file
								 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
								 */
								get_template_part( 'template-parts/content', 'layout' );
							?>

						<?php endwhile; ?>

					<?php else : ?>

						<?php get_template_part( 'no-results', 'archive' ); ?>

					<?php endif; ?>
				</div>

				<?php
				if ( have_posts() ) :
					the_posts_navigation();
				endif;
				?>

			</div>

		</div><!-- #content -->
	</section><!-- #primary .site-content -->

<?php get_footer(); ?>
