<?php
/**
 * @package Mono
 */

/**
 * Get the array of definitions for Customizer settings and controls.
 *
 * @since 1.0.0.
 *
 * @param  object $wp_customize    The Customizer instance.
 *
 * @return mixed|void
 */
function mono_customize_get_definitions( $wp_customize ) {
	$google_fonts = mono_all_font_choices();

	$definitions = array(
		'colors'           => array(
			'title'       => esc_html__( 'Colors', 'mono' ),
			'description' => '',
			'priority'    => '',
			'options'     => array(
				'color-accent'            => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Accent', 'mono' ),
					),
				),
				'color-footer-background' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Footer Background', 'mono' ),
					),
				),
			),
		),
		'mono_fonts'       => array(
			'title'       => esc_html__( 'Fonts', 'mono' ),
			'description' => sprintf(
				/* translators: %s: Google fonts website */
				esc_html__(
					'The list of Google fonts is long! You can %s before making your choices.',
					'mono'
				),
				sprintf(
					'<a href="%1$s" target="_blank">%2$s</a>',
					esc_url( 'https://www.google.com/fonts' ),
					esc_html__( 'preview', 'mono' )
				)
			),
			'priority'    => $wp_customize->get_section( 'colors' )->priority + 1,
			'options'     => array(
				'font-body'          => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Body', 'mono' ),
					),
				),
				'font-headers'       => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Headers', 'mono' ),
					),
				),
				'google-font-subset' => array(
					'setting' => array(),
					'control' => array(
						'type'        => 'select',
						'choices'     => mono_get_google_font_subsets(),
						'label'       => esc_html__( 'Google Font Subset', 'mono' ),
						'description' => sprintf(
							/* translators: %s: Google fonts website */
							esc_html__(
								'Not all fonts provide each of these subsets. Please visit the %s to see which subsets are available for each font.',
								'mono'
							),
							sprintf(
								'<a href="%1$s" target="_blank">%2$s</a>',
								esc_url( 'https://www.google.com/fonts' ),
								esc_html__( 'Google Fonts website', 'mono' )
							)
						),
					),
				),
			),
		),
		'background_image' => array(
			'options' => array(
				'use-background-cover' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Use as Background Cover', 'mono' ),
						'description' => esc_html__( 'Checking this option will strech background image as background cover with fixed width and height.', 'mono' ),
					),
				),
			),
		),
		'theme_options'    => array(
			'title'       => esc_html__( 'Theme Options', 'mono' ),
			'description' => '',
			'priority'    => $wp_customize->get_section( 'background_image' )->priority + 1,
			'options'     => array(
				'hide-author-avatar'   => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Hide Author Avatar', 'mono' ),
						'description' => esc_html__( 'Check to hide author avatar on single post cover', 'mono' ),
					),
				),
				'center-post-cover'    => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'  => 'checkbox',
						'label' => esc_html__( 'Center Post Cover Content', 'mono' ),
					),
				),
				'archive-posts-layout' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'select',
						'choices'     => array(
							'tile' => esc_html__( 'Tile', 'mono' ),
							'grid' => esc_html__( 'Grid', 'mono' ),
						),
						'label'       => esc_html__( 'Archive Layout', 'mono' ),
						'description' => esc_html__( 'Choose a posts layout, applies on post archives.', 'mono' ),
					),
				),
				'html-footer-text'     => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Footer Text', 'mono' ),
					),
				),
				'bool-hide-credit'     => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'  => 'checkbox',
						'label' => esc_html__( 'Hide theme byline', 'mono' ),
					),
				),
			),
		),
	);

	/**
	 * Filter the control definitions for the Customizer.
	 *
	 * '[section_id]' => array(
	 *     'title' => esc_html__( '[Section Title]', 'mono' ),
	 *     'description' => esc_html__( '[Section description]', 'mono' ),
	 *     'options' => array(
	 *         '[setting-id]' => array(
	 *             'setting' => array(
	 *                 [setting-parameter] => [value]
	 *             ),
	 *             'control' => array(
	 *                 [control-parameter] => [value]
	 *             ),
	 *         ),
	 *     ),
	 * ),
	 *
	 * @since 1.0.0.
	 *
	 * @param array    $definitions    The array containing all of the Customizer definitions.
	 */
	$definitions = apply_filters( 'mono_customizer_definitions', $definitions );

	return $definitions;
}
