<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: http://codex.wordpress.org/Template_Hierarchy
 *
 * @package Mono
 */

global $mono_settings;

$post_layout = $mono_settings->get_value( 'archive-posts-layout' );
$layout_class = 'grid';

if ( 'grid' == $post_layout ) {
	$layout_class .= ' posts-list';
} else if ( 'tile' == $post_layout ) {
	$layout_class .= ' recent-posts-layout-tile';
} else if ( 'compact' == $post_layout ) {
	$layout_class .= ' recent-posts-layout-compact';
}

$container_class = 'container';
if ( 'tile' == $post_layout ) {
	$container_class = 'container--tile';
}

get_header(); ?>

	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">
			<div class="<?php echo esc_attr( $container_class ); ?>">

				<div class="<?php echo esc_attr( $layout_class ) ?>">
					<?php if ( have_posts() ) : ?>

						<?php /* Start the Loop */ ?>
						<?php while ( have_posts() ) : the_post(); ?>

							<?php
								/* Include the Post-Format-specific template for the content.
								 * If you want to override this in a child theme, then include a file
								 * called content-___.php (where ___ is the Post Format name) and that will be used instead.
								 */
								get_template_part( 'template-parts/content', 'layout' );
							?>

						<?php endwhile; ?>

					<?php else : ?>

						<?php get_template_part( 'content', 'none' ); ?>

					<?php endif; ?>
				</div>

				<?php if ( have_posts() ) :
					the_posts_navigation();
				endif; ?>

			</div>
		</main><!-- #main -->
	</div><!-- #primary -->

<?php get_footer(); ?>
